@@ -103,6 +103,9 @@
 #define SYS_CLASS_POWER_SUPPLY	"/sys/class/power_supply"
 #define PROC_ACPI_BATTERY	"/proc/acpi/battery"
 
+#define FLOAT_TINY		(0.0000001)
+#define FLOAT_CMP(a, b)		(fabs(a - b) < FLOAT_TINY)
+
 #define SYS_FIELD_VOLTAGE_NOW		"POWER_SUPPLY_VOLTAGE_NOW="
 #define SYS_FIELD_POWER_NOW		"POWER_SUPPLY_POWER_NOW="
 #define SYS_FIELD_ENERGY_NOW		"POWER_SUPPLY_ENERGY_NOW="
@@ -110,6 +113,7 @@
 #define SYS_FIELD_CHARGE_NOW		"POWER_SUPPLY_CHARGE_NOW="
 #define SYS_FIELD_STATUS_DISCHARGING  	"POWER_SUPPLY_STATUS=Discharging"
 
+
 #if defined(__x86_64__) || defined(__x86_64) || \
     defined(__i386__) || defined(__i386)
 #define RAPL_X86
@@ -1093,7 +1097,7 @@ static int power_get_proc_acpi(
 		 * 'present voltage' field and instead returns this in
 		 * the design_voltage field, so work around this.
 		 */
-		if (voltage == 0.0) {
+		if (FLOAT_CMP(voltage, 0.0)) {
 			sprintf(filename, "/proc/acpi/battery/%s/info",
 				dirent->d_name);
 			if ((file = fopen(filename, "r")) != NULL) {
@@ -1396,11 +1400,13 @@ static inline int monitor(
 	int readings = 0, i;
 	int64_t t = 1;
 	stats_t *stats, s1, s2, average, stddev;
-	bool discharging, dummy_inaccurate;
+	bool dummy_inaccurate;
 	double time_start;
 
 	if (start_delay > 0) {
 		stats_t dummy;
+		bool discharging;
+
 		/* Gather up initial data */
 		for (i = 0; i < start_delay; i++) {
 			if (opt_flags & OPT_PROGRESS) {
@@ -1727,7 +1733,7 @@ static double calc_average_voltage(
 	}
 	average = (n == 0) ? 0.0 : average / n;
 
-	if (average == 0.0)
+	if (FLOAT_CMP(average, 0.0))
 		return -1;
 
 	return average;
